##  Overview
SAP LeanIX is migrating all customers to a new single sign-on (SSO) service. This migration requires active changes in your Identity Provider (IdP) and workspace‑specific SSO configurations in SAP LeanIX. During the migration, your users don't experience any disruptions and can always access your workspaces.
Access issues can occur during migration when:
  * The workspace-specific IdP configuration is missing.
  * Attribute names were not updated to the new version.
  * Production and sandbox workspaces are still associated with the same IdP application.


This guide covers the steps needed to migrate to the new SSO service.
